@@ -34,7 +34,7 @@ void clear_insn_cache(u32 start, u32 end, u32 type)
 }
 #endif
 
-#ifdef PANDORA
+#if defined(PANDORA) && !defined(__SYMBIAN32__)
 static void clear_insn_cache(u32 start, u32 end, int type) 
 {
   //flush cache
